@@ -4,7 +4,7 @@ from os.path import dirname, join
 from sklearn.utils import Bunch
 
 
-def load_yaz(include_prod=None, include_lag=False, include_date=False, one_hot_encoding=False,
+def load_yaz(include_date=False, one_hot_encoding=False,
              label_encoding=False, return_X_y=False):
     """Load and return the YAZ dataset
 
@@ -14,11 +14,11 @@ def load_yaz(include_prod=None, include_lag=False, include_date=False, one_hot_e
 
     **Dataset Characteristics:**
 
-        :Number of Instances: 760
+        :Number of Instances: 765
 
         :Number of Targets: 7
 
-        :Number of Features: 10
+        :Number of Features: 12
 
         :Target Information:
             - 'calamari' the demand for calamari
@@ -30,28 +30,21 @@ def load_yaz(include_prod=None, include_lag=False, include_date=False, one_hot_e
             - 'steak' the demand for steak
 
         :Feature Information:
+            - 'date' the date,
             - 'weekday' the day of the week,
             - 'month' the month of the year,
             - 'year' the year,
             - 'is_holiday' whether or not it is a national holiday,
+            - 'is_closed' whether or not the restaurant is closed,
             - 'weekend' whether or not it is weekend,
             - 'wind' the wind force,
             - 'clouds' the cloudiness degree,
-            - 'rainfall' the amount of rainfall,
+            - 'rain' the amount of rain,
             - 'sunshine' the sunshine hours,
             - 'temperature' the outdoor temperature,
 
-        Note: The dataset also includes demand lag features as well as a column for the demand date.
-        By default, those features are not included when loading the data. You can include them
-        by setting the parameter `include_lag`/`include_date` to `True`.
-
     Parameters
     ----------
-    include_prod : 1d array or list , default=None
-        List of products to include. Valid products are {"steak", "chicken", "koefte", "lamb", "fish", "shrimp",
-        "calamari"}. If None, all products are included
-    include_lag : bool, default=False
-        Whether to include lag features
     include_date : bool, default=False
         Whether to include the demand date
     one_hot_encoding : bool, default=False
@@ -68,13 +61,10 @@ def load_yaz(include_prod=None, include_lag=False, include_date=False, one_hot_e
     data : sklearn Bunch
         Dictionary-like object, with the following attributes.
 
-        data : Pandas DataFrame of shape (760, n_features)
+        data : Pandas DataFrame of shape (765, n_features)
             The data matrix.
-        target: Pandas DataFrame of shape (760, n_targets)
+        target: Pandas DataFrame of shape (765, n_targets)
             The target values.
-        frame: pandas DataFrame of shape (760, n_features+n_targets)
-            Only present when `as_frame=True`. Pandas DataFrame with `data` and
-            `target`.
         n_features: int
             The number of features included
         n_targets: int
@@ -88,12 +78,12 @@ def load_yaz(include_prod=None, include_lag=False, include_date=False, one_hot_e
 
     (data, target) : tuple if ``return_X_y`` is True
 
-    Examples:
-    ----------
+    Examples
+    ---------
     >>> from ddop.datasets import load_yaz
     >>> X, y = load_yaz(return_X_y=True)
     >>> print(X.shape)
-        (760, 10)
+        (765, 11)
     """
 
     module_path = dirname(__file__)
@@ -109,75 +99,24 @@ def load_yaz(include_prod=None, include_lag=False, include_date=False, one_hot_e
     if not include_date:
         data = data.drop('date', axis=1)
 
-    feature_terms_to_drop = []
-    targets_to_drop = []
-
-    if not include_lag:
-        for term in ["_t1", "_t2", "_t3", "_t4", "_t5", "_t6", "_t7", "_w2", "_w3", "_w4"]:
-            feature_terms_to_drop.append(term)
-
-    if include_prod is not None:
-
-        products = ["steak", "chicken", "koefte", "lamb", "fish", "shrimp", "calamari"]
-
-        if not np.any([prod in products for prod in include_prod]):
-            raise ValueError(
-                "No valid product in include_prod. If you specify this parameter, please select at least one valid "
-                "product. Supported are %s" % (list(products)))
-
-        if "lamb" not in include_prod:
-            feature_terms_to_drop.append("lamb")
-            targets_to_drop.append("lamb")
-
-        if "steak" not in include_prod:
-            feature_terms_to_drop.append("steak")
-            targets_to_drop.append("steak")
-
-        if "koefte" not in include_prod:
-            feature_terms_to_drop.append("koefte")
-            targets_to_drop.append("koefte")
-
-        if "chicken" not in include_prod:
-            feature_terms_to_drop.append("chicken")
-            targets_to_drop.append("chicken")
-
-        if "shrimp" not in include_prod:
-            feature_terms_to_drop.append("shrimp")
-            targets_to_drop.append("shrimp")
-
-        if "fish" not in include_prod:
-            feature_terms_to_drop.append("fish")
-            targets_to_drop.append("fish")
-
-        if "calamari" not in include_prod:
-            feature_terms_to_drop.append("calamari")
-            targets_to_drop.append("calamari")
-
-    for col in data.columns:
-        if np.any([term in col for term in feature_terms_to_drop]):
-            data = data.drop(col, 1)
-
-    target = target.drop(targets_to_drop, axis=1)
-
     n_features = data.shape[0]
     n_targets = data.shape[1]
 
     if one_hot_encoding:
         data = pd.get_dummies(data, columns=["weekday", "month", "year"])
 
-    if not one_hot_encoding and label_encoding:
+    elif not one_hot_encoding and label_encoding:
         data['weekday'] = data['weekday'].apply(_day_to_continuouse)
         data['month'] = data['month'].apply(_month_to_continuouse)
-        data['year'] = data['year'].apply(int)
 
-    frame = pd.concat([data, target], axis=1)
+    else:
+        data['year'] = data['year'].apply(str)
 
     if return_X_y:
         return data, target
 
     return Bunch(data=data,
                  target=target,
-                 frame=frame,
                  n_features=n_features,
                  n_targets=n_targets,
                  DESCR=fdescr,
@@ -185,48 +124,41 @@ def load_yaz(include_prod=None, include_lag=False, include_date=False, one_hot_e
                  target_filename=target_filename)
 
 
-def load_bakery(include_prod=None, include_lag=False, include_date=False, one_hot_encoding=False,
+def load_bakery(include_date=False, one_hot_encoding=False,
              label_encoding=False, return_X_y=False):
     """Load and return the bakery dataset
 
-    The bakery dataset contains the demand for rolls, seeded rolls and pretzels. Moreover, it stores a
+    The bakery dataset contains the demand for a number of products from different stores. Moreover, it stores a
     number of demand features. A description of targets and features is given below.
 
     **Dataset Characteristics:**
 
-        :Number of Instances: 1155
+        :Number of Instances: 127575
 
-        :Number of Targets: 3
+        :Number of Targets: 1
 
-        :Number of Features: 9
+        :Number of Features: 13
 
         :Target Information:
-            - 'roll' the demand for rolls
-            - 'seeded_roll' the demand for seeded rolls
-            - 'pretzel' the demand for pretzels
+            - 'demand' the corresponding demand observation
 
         :Feature Information:
+            - 'date' the date
             - 'weekday' the day of the week,
             - 'month' the month of the year,
             - 'year' the year,
-            - 'is_holiday' whether or not it is a national holiday
+            - 'is_holiday' whether or not it is a national holiday,
+            - 'is_holiday_next2days' whether or not it is a national holiday in the next two days,
             - 'is_schoolholiday' whether or not it is a school holiday,
-            - 'rainfall' the amount of rainfall,
-            - 'temperature' the outdoor temperature,
+            - 'store' the store id,
+            - 'product' the product id,
+            - 'rain' the amount of rain,
+            - 'temperature' the average temperature in °C,
             - 'promotion_currentweek' whether or not there is a promotion this week
             - 'promotion_lastweek' whether there was a promotion last week
 
-        Note: The dataset also includes demand lag features as well as a column for the demand date.
-        By default, those features are not included when loading the data. You can include them
-        by setting the parameter `include_lag`/`include_date` to `True`.
-
     Parameters
     ----------
-    include_prod : 1d array or list , default=None
-        List of products to include. Valid products are {"roll", "seeded_roll", "pretzel"}.
-        If None, all products are included
-    include_lag : bool, default=False
-        Whether to include lag features
     include_date : bool, default=False
         Whether to include the demand date
     one_hot_encoding : bool, default=False
@@ -243,13 +175,10 @@ def load_bakery(include_prod=None, include_lag=False, include_date=False, one_ho
     data : sklearn Bunch
         Dictionary-like object, with the following attributes.
 
-        data : Pandas DataFrame of shape (1155, n_features)
+        data : Pandas DataFrame of shape (127575, n_features)
             The data matrix.
-        target: Pandas DataFrame of shape (1155, n_targets)
+        target: Pandas DataFrame of shape (127575, n_targets)
             The target values.
-        frame: pandas DataFrame of shape (1155, n_features+n_targets)
-            Only present when `as_frame=True`. Pandas DataFrame with `data` and
-            `target`.
         n_features: int
             The number of features included
         n_targets: int
@@ -260,15 +189,14 @@ def load_bakery(include_prod=None, include_lag=False, include_date=False, one_ho
             The path to the location of the data.
         target_filename: str
             The path to the location of the target.
-
     (data, target) : tuple if ``return_X_y`` is True
 
-    Examples:
+    Examples
     ----------
     >>> from ddop.datasets import load_bakery
     >>> X, y = load_bakery(return_X_y=True)
     >>> print(X.shape)
-        (1155, 9)
+        (127575, 12)
     """
 
     module_path = dirname(__file__)
@@ -284,44 +212,116 @@ def load_bakery(include_prod=None, include_lag=False, include_date=False, one_ho
     if not include_date:
         data = data.drop('date', axis=1)
 
-    feature_terms_to_drop = []
-    targets_to_drop = []
+    n_features = data.shape[0]
+    n_targets = data.shape[1]
+
+    if one_hot_encoding:
+        data = pd.get_dummies(data, columns=["weekday", "month", "year"])
+
+    elif not one_hot_encoding and label_encoding:
+        data['weekday'] = data['weekday'].apply(_day_to_continuouse)
+        data['month'] = data['month'].apply(_month_to_continuouse)
 
-    if not include_lag:
-        for term in ["_t1", "_t2", "_t3", "_t4", "_t5", "_t6", "_t7", "_w2", "_w3", "_w4"]:
-            feature_terms_to_drop.append(term)
     else:
-        data.drop(data.index[:28], inplace=True)
-        data.reset_index(drop=True, inplace=True)
-        target.drop(data.index[:28], inplace=True)
-        target.reset_index(drop=True, inplace=True)
+        data['year'] = data['year'].apply(str)
 
-    if include_prod is not None:
+    if return_X_y:
+        return data, target
 
-        products = ["roll", "seeded_roll", "pretzel"]
+    return Bunch(data=data,
+                 target=target,
+                 n_features=n_features,
+                 n_targets=n_targets,
+                 DESCR=fdescr,
+                 data_filename=data_filename,
+                 target_filename=target_filename)
 
-        if not np.any([prod in products for prod in include_prod]):
-            raise ValueError(
-                "No valid product in include_prod. If you specify this parameter, please select at least one valid "
-                "product. Supported are %s" % (list(products)))
 
-        if "roll" not in include_prod:
-            targets_to_drop.append("roll")
-            feature_terms_to_drop.append("roll")
+def load_SID(include_date=False, one_hot_encoding=False,
+             label_encoding=False, return_X_y=False):
 
-        if "seeded_roll" not in include_prod:
-            targets_to_drop.append("seeded_roll")
-            feature_terms_to_drop.append("seeded_roll")
+    """Load and return the store item demand dataset.
 
-        if "pretzel" not in include_prod:
-            targets_to_drop.append("pretzel")
-            feature_terms_to_drop.append("pretzel")
+    **Dataset Characteristics:**
 
-    for col in data.columns:
-        if np.any([term in col for term in feature_terms_to_drop]):
-            data = data.drop(col, 1)
+        :Number of Instances: 887284
 
-    target = target.drop(targets_to_drop, axis=1)
+        :Number of Targets: 1
+
+        :Number of Features: 6
+
+        :Target Information:
+            - 'demand' the corresponding demand observation
+
+        :Feature Information:
+            - 'date' the date
+            - 'weekday' the day of the week,
+            - 'month' the month of the year,
+            - 'year' the year,
+            - 'store' the store id,
+            - 'item' the item id
+    Parameters
+    ----------
+    include_date : bool, default=False
+        Whether to include the demand date
+    one_hot_encoding : bool, default=False
+        Whether to one hot encode categorical features
+    label_encoding : bool, default=False
+        Whether to convert categorical columns (weekday, month, year) to continuous.
+        Will only be applied if `one_hot_encoding=False`
+    return_X_y : bool, default=False.
+        If True, returns ``(data, target)`` instead of a Bunch object.
+        See below for more information about the `data` and `target` object.
+
+    Returns
+    -------
+    data : sklearn Bunch
+        Dictionary-like object, with the following attributes.
+
+        data : Pandas DataFrame of shape (887284, n_features)
+            The data matrix.
+        target: Pandas DataFrame of shape (887284, n_targets)
+            The target values.
+        n_features: int
+            The number of features included
+        n_targets: int
+            The number of target variables included
+        DESCR: str
+            The full description of the dataset.
+        data_filename: str
+            The path to the location of the data.
+        target_filename: str
+            The path to the location of the target.
+    (data, target): tuple if ``return_X_y`` is True
+
+    Notes
+    -----
+    The store item demand dataset was published within a demand forecasting challenge on kaggle [1]
+
+    References
+    ----------
+    .. [1] https://www.kaggle.com/c/demand-forecasting-kernels-only/overview
+
+    Examples
+    --------
+    >>> from ddop.datasets import load_SID
+    >>> X, y = load_SID(return_X_y=True)
+    >>> print(X.shape)
+        (887284, 5)
+    """
+
+    module_path = dirname(__file__)
+    base_dir = join(module_path, 'data')
+    data_filename = join(base_dir, 'SID_data.csv')
+    data = pd.read_csv(data_filename)
+    target_filename = join(base_dir, 'SID_target.csv')
+    target = pd.read_csv(target_filename)
+
+    with open(join(module_path, 'descr', 'SID.rst')) as rst_file:
+        fdescr = rst_file.read()
+
+    if not include_date:
+        data = data.drop('date', axis=1)
 
     n_features = data.shape[0]
     n_targets = data.shape[1]
@@ -329,19 +329,18 @@ def load_bakery(include_prod=None, include_lag=False, include_date=False, one_ho
     if one_hot_encoding:
         data = pd.get_dummies(data, columns=["weekday", "month", "year"])
 
-    if not one_hot_encoding and label_encoding:
+    elif not one_hot_encoding and label_encoding:
         data['weekday'] = data['weekday'].apply(_day_to_continuouse)
         data['month'] = data['month'].apply(_month_to_continuouse)
-        data['year'] = data['year'].apply(int)
 
-    frame = pd.concat([data, target], axis=1)
+    else:
+        data['year'] = data['year'].apply(str)
 
     if return_X_y:
         return data, target
 
     return Bunch(data=data,
                  target=target,
-                 frame=frame,
                  n_features=n_features,
                  n_targets=n_targets,
                  DESCR=fdescr,
@@ -390,5 +389,4 @@ def _day_to_continuouse(x):
     elif x=='SAT':
         return 6
     else:
-        return 7
-
+        return 7
\ No newline at end of file
